@@ -42,7 +42,12 @@
 #include "plugin_setup.h"
 #include "plugin_types.h"
 #include "plugin_dbus.h"
+#include "nsIPrefBranch.h"
+#include "nsIPrefService.h"
+#include "nsIServiceManager.h"
 
+nsIPrefBranch *prefBranch = NULL;
+nsIPrefService *prefService = NULL;
 static NPObject *sWindowObj;
 
 //#include "nsIServiceManager.h"
@@ -161,17 +166,68 @@ void NS_DestroyPluginInstance(CPlugin * aPlugin)
 
 
 */
-void postDOMEvent(NPP mInstance, const gchar *id, const gchar *event) {
+void postDOMEvent(NPP mInstance, const gchar * id, const gchar * event)
+{
     gchar *jscript;
 
     jscript = g_strdup_printf("javascript:obj=document.getElementById('%s');"
-                                "e=document.createEvent('Events');"
-                                "e.initEvent('%s',true,true);"
-                                "obj.dispatchEvent(e);",id,event);
+                              "e=document.createEvent('Events');"
+                              "e.initEvent('%s',true,true);" "obj.dispatchEvent(e);", id, event);
     NPN_GetURL(mInstance, jscript, NULL);
     g_free(jscript);
 }
 
+void setPreference(CPlugin * instance, const gchar * name, const gchar * value)
+{
+    nsIServiceManager *sm = NULL;
+    NPN_GetValue(NULL, NPNVserviceManager, &sm);
+    PRBool v;
+
+    if (sm) {
+
+        sm->GetServiceByContractID("@mozilla.org/preferences-service;1", NS_GET_IID(nsIPrefService), (void **)&prefService);
+        if (prefService) {
+            prefService->GetBranch("", &prefBranch);
+            if (prefBranch) {
+                instance->user_agent = g_new0(gchar, 1024);
+                prefBranch->PrefHasUserValue(name,&v);
+                if (v)
+                    prefBranch->GetCharPref(name, &(instance->user_agent));
+                prefBranch->SetCharPref(name, value);
+            }
+        }
+        NS_RELEASE(sm);
+    }
+
+}
+
+void clearPreference(CPlugin * instance, const gchar * name)
+{
+    nsIServiceManager *sm = NULL;
+    NPN_GetValue(NULL, NPNVserviceManager, &sm);
+
+    if (sm) {
+
+        sm->GetServiceByContractID("@mozilla.org/preferences-service;1", NS_GET_IID(nsIPrefService), (void **)&prefService);
+        if (prefService) {
+            prefService->GetBranch("", &prefBranch);
+            if (prefBranch) {
+                if (instance->user_agent == NULL || strlen(instance->user_agent) == 0) {
+                    prefBranch->ClearUserPref(name);
+                } else {
+                    if (g_strrstr(instance->user_agent,"QuickTime/7.6.2")) {
+                        prefBranch->ClearUserPref(name);
+                    } else {
+                        prefBranch->SetCharPref(name, instance->user_agent);
+                    }
+                }
+                g_free(instance->user_agent);
+            }
+        }
+        NS_RELEASE(sm);
+    }
+}
+
 ////////////////////////////////////////
 //
 // CPlugin class implementation
@@ -202,6 +258,7 @@ name(NULL),
 id(NULL),
 console(NULL),
 controls(NULL),
+user_agent(NULL),
 disable_context_menu(FALSE),
 disable_fullscreen(FALSE),
 post_dom_events(FALSE),
@@ -214,7 +271,6 @@ tv_driver(NULL), tv_device(NULL), tv_input(NULL), tv_width(0), tv_height(0)
 {
     GRand *rand;
     GmPrefStore *store;
-    gchar *jscript;
 
     NPN_GetValue(mInstance, NPNVWindowNPObject, &sWindowObj);
 
@@ -305,6 +361,7 @@ tv_driver(NULL), tv_device(NULL), tv_input(NULL), tv_width(0), tv_height(0)
     if (connection == NULL) {
         connection = dbus_hookup(this);
     }
+    pluginSpecific(this);
     
     mInitialized = TRUE;
 }
@@ -331,6 +388,8 @@ CPlugin::~CPlugin()
         NS_IF_RELEASE(mControlsScriptablePeer);
     }
 */
+    clearPreference(this, "general.useragent.override");
+
     if (m_pScriptableObjectControls) {
         NPN_ReleaseObject(m_pScriptableObjectControls);
     }
@@ -555,8 +614,10 @@ NPError CPlugin::DestroyStream(NPStream * stream, NPError reason)
             ready = item->playerready;
             newwindow = item->newwindow;
             playlist = list_parse_qt(playlist, item);
+            playlist = list_parse_qt2(playlist, item);
             playlist = list_parse_asx(playlist, item);
             playlist = list_parse_qml(playlist, item);
+            playlist = list_parse_ram(playlist, item);
             if (item->play) {
                 open_location(this, item, TRUE);
                 if (post_dom_events && this->id != NULL) {
@@ -608,8 +669,8 @@ NPError CPlugin::DestroyStream(NPStream * stream, NPError reason)
 void CPlugin::URLNotify(const char *url, NPReason reason, void *notifyData)
 {
     ListItem *item = (ListItem *) notifyData;
-    DBusMessage *message;
-    const char *file;
+    //DBusMessage *message;
+    //const char *file;
 
     printf("URL Notify %s\n,%i = %i\n%s\n%s\n%s\n", url, reason, NPRES_DONE, item->src, item->local,
            path);
@@ -630,6 +691,19 @@ void CPlugin::URLNotify(const char *url, NPReason reason, void *notifyData)
                dbus_message_unref(message);
              */
         }
+    } else {
+        if (item)
+            item->played = TRUE;
+        if (!item->streaming) {
+            item = list_find_next_playable(playlist);
+            if (item) {
+                if (item->retrieved) {
+                    open_location(this, item, TRUE);
+                } else {
+                    NPN_GetURLNotify(mInstance, item->src, NULL, item);
+                }
+            }
+        }
     }
 }
 
@@ -660,16 +734,16 @@ int32 CPlugin::WriteReady(NPStream * stream)
             playlist = g_list_append(playlist, item);
             stream->notifyData = item;
         } else {
-            printf("item is null\nstream url %s\n", stream->url);
+            // printf("item is null\nstream url %s\n", stream->url);
             NPN_DestroyStream(mInstance, stream, NPRES_DONE);
             return -1;
         }
     } else {
-        if (g_ascii_strcasecmp(item->src,stream->url) != 0) {
-            g_strlcpy(item->src,stream->url,4096);
+        if (g_ascii_strcasecmp(item->src, stream->url) != 0) {
+            g_strlcpy(item->src, stream->url, 4096);
         }
     }
-            
+
     // printf("Write Ready item url = %s\n%s\n",item->src,stream->url);
 
     if (item->cancelled)
@@ -740,18 +814,11 @@ int32 CPlugin::Write(NPStream * stream, int32 offset, int32 len, void *buffer)
     if (item->cancelled || item->retrieved)
         NPN_DestroyStream(mInstance, stream, NPRES_USER_BREAK);
 
-    if (strstr((char *) buffer, "ICY 200 OK") != NULL || item->streaming == TRUE) {
-        item->streaming = TRUE;
-        open_location(this, item, FALSE);
-        item->requested = TRUE;
-        if (item->localfp) {
-            fclose(item->localfp);
-        }
-        NPN_DestroyStream(mInstance, stream, NPRES_DONE);
-        return -1;
-    }
-    // If item is a block of jpeg images, just stream it
-    if (strstr((char *) buffer, "Content-length:") != NULL || item->streaming == TRUE) {
+    if (strstr((char *) buffer, "ICY 200 OK") != NULL 
+        || strstr((char *) buffer, "Content-length:") != NULL // If item is a block of jpeg images, just stream it
+        || strstr((char *) buffer, "<HTML>") != NULL
+        || item->streaming == TRUE
+        || stream->lastmodified == 0) {
         item->streaming = TRUE;
         open_location(this, item, FALSE);
         if (post_dom_events && this->id != NULL) {
@@ -761,26 +828,12 @@ int32 CPlugin::Write(NPStream * stream, int32 offset, int32 len, void *buffer)
         if (item->localfp) {
             fclose(item->localfp);
         }
-        NPN_DestroyStream(mInstance, stream, NPRES_DONE);
-        return -1;
-    }
-
-    if (strstr((char *) buffer, "<HTML>") != NULL || item->streaming == TRUE) {
-        item->streaming = TRUE;
-        open_location(this, item, FALSE);
-        if (post_dom_events && this->id != NULL) {
-            postDOMEvent(mInstance, this->id, "qt_play");
-        }
-        item->requested = TRUE;
-        if (item->localfp) {
-            fclose(item->localfp);
-        }
-        NPN_DestroyStream(mInstance, stream, NPRES_DONE);
+        NPN_DestroyStream(mInstance, stream, NPRES_USER_BREAK);
         return -1;
     }
 
     if ((!item->localfp) && (!item->retrieved)) {
-        printf("opening %s for localcache\n", item->local);
+        // printf("opening %s for localcache\n", item->local);
         item->localfp = fopen(item->local, "w+");
     }
     // printf("Write item url = %s\n",item->src);
@@ -808,14 +861,13 @@ int32 CPlugin::Write(NPStream * stream, int32 offset, int32 len, void *buffer)
                     (gdouble) ((item->localsize -
                                 item->lastsize) / 1024.0) / (gdouble) difftime(time(NULL),
                                                                                lastupdate);
-                text =
-                    g_strdup_printf(_("Cache fill: %2.2f%% (%0.1f K/s)"), percent * 100.0,
-                                    rate);
+                text = g_strdup_printf(_("Cache fill: %2.2f%% (%0.1f K/s)"), percent * 100.0, rate);
                 send_signal_with_string(this, item, "SetProgressText", text);
                 if (!item->opened)
                     send_signal_with_string(this, item, "SetURL", item->src);
                 if (post_dom_events && this->id != NULL) {
                     postDOMEvent(mInstance, this->id, "qt_progress");
+                    postDOMEvent(mInstance, this->id, "qt_durationchange");
                 }
 
                 time(&lastupdate);
@@ -823,13 +875,15 @@ int32 CPlugin::Write(NPStream * stream, int32 offset, int32 len, void *buffer)
             }
         }
         if (!item->opened) {
+            send_signal_with_integer(this, item, "SetGUIState", PLAYING);
             if ((item->localsize >= (cache_size * 1024)) && (percent >= 0.2))
                 ok_to_play = TRUE;
             if (ok_to_play == FALSE && (item->localsize > (cache_size * 2 * 1024))
                 && (cache_size >= 512))
                 ok_to_play = TRUE;
             if (ok_to_play == FALSE) {
-                if (item->bitrate == 0 && item->bitrate_requests < 5 && ((gint)(percent * 100) > item->bitrate_requests)) {
+                if (item->bitrate == 0 && item->bitrate_requests < 5
+                    && ((gint) (percent * 100) > item->bitrate_requests)) {
                     item->bitrate = request_bitrate(this, item, item->local);
                     item->bitrate_requests++;
                 }
@@ -853,9 +907,11 @@ int32 CPlugin::Write(NPStream * stream, int32 offset, int32 len, void *buffer)
             playlist = list_parse_qt(playlist, item);
             playlist = list_parse_asx(playlist, item);
             playlist = list_parse_qml(playlist, item);
+            playlist = list_parse_ram(playlist, item);
             if (item->play) {
                 open_location(this, item, TRUE);
                 if (post_dom_events && this->id != NULL) {
+                    postDOMEvent(mInstance, this->id, "qt_loadedfirstframe");
                     postDOMEvent(mInstance, this->id, "qt_canplay");
                     postDOMEvent(mInstance, this->id, "qt_play");
                 }
@@ -1150,7 +1206,8 @@ class ScriptablePluginObjectBase:public NPObject {
   public:
     ScriptablePluginObjectBase(NPP npp)
     :mNpp(npp) {
-    } virtual ~ ScriptablePluginObjectBase() {
+    }
+    virtual ~ ScriptablePluginObjectBase() {
     }
 
     // Virtual NPObject hooks called through this base class. Override
@@ -1310,7 +1367,8 @@ class ScriptablePluginObjectControls:public ScriptablePluginObjectBase {
   public:
     ScriptablePluginObjectControls(NPP npp)
     :ScriptablePluginObjectBase(npp) {
-    } virtual bool HasMethod(NPIdentifier name);
+    }
+    virtual bool HasMethod(NPIdentifier name);
     virtual bool Invoke(NPIdentifier name, const NPVariant * args,
                         uint32_t argCount, NPVariant * result);
     virtual bool InvokeDefault(const NPVariant * args, uint32_t argCount, NPVariant * result);
@@ -1325,7 +1383,8 @@ static NPObject *AllocateScriptablePluginObjectControls(NPP npp, NPClass * aClas
     return new ScriptablePluginObjectControls(npp);
 }
 
-DECLARE_NPOBJECT_CLASS_WITH_BASE(ScriptablePluginObjectControls, AllocateScriptablePluginObjectControls);
+DECLARE_NPOBJECT_CLASS_WITH_BASE(ScriptablePluginObjectControls,
+                                 AllocateScriptablePluginObjectControls);
 
 bool ScriptablePluginObjectControls::HasMethod(NPIdentifier name)
 {
@@ -1333,8 +1392,7 @@ bool ScriptablePluginObjectControls::HasMethod(NPIdentifier name)
         name == controls_pause_id ||
         name == controls_stop_id ||
         name == controls_fastForward_id ||
-        name == controls_fastReverse_id ||
-        name == controls_step_id) {
+        name == controls_fastReverse_id || name == controls_step_id) {
         return true;
     } else {
         return false;
@@ -1342,7 +1400,7 @@ bool ScriptablePluginObjectControls::HasMethod(NPIdentifier name)
 }
 
 bool ScriptablePluginObjectControls::Invoke(NPIdentifier name, const NPVariant * args,
-                                    uint32_t argCount, NPVariant * result)
+                                            uint32_t argCount, NPVariant * result)
 {
     CPlugin *pPlugin = (CPlugin *) mNpp->pdata;
     if (pPlugin == NULL) {
@@ -1369,7 +1427,7 @@ bool ScriptablePluginObjectControls::Invoke(NPIdentifier name, const NPVariant *
 }
 
 bool ScriptablePluginObjectControls::InvokeDefault(const NPVariant * args, uint32_t argCount,
-                                           NPVariant * result)
+                                                   NPVariant * result)
 {
     printf("ScriptablePluginObject default method called!\n");
 
@@ -1400,9 +1458,9 @@ bool ScriptablePluginObjectControls::GetProperty(NPIdentifier name, NPVariant *
 
     if (name == controls_currentPosition_id) {
         pPlugin->GetTime(&position);
-        DOUBLE_TO_NPVARIANT(position,*result);
+        DOUBLE_TO_NPVARIANT(position, *result);
         return true;
-    }                
+    }
 
     VOID_TO_NPVARIANT(*result);
     return false;
@@ -1419,7 +1477,7 @@ bool ScriptablePluginObjectControls::SetProperty(NPIdentifier name, const NPVari
     if (name == controls_currentPosition_id) {
         pPlugin->Seek(NPVARIANT_TO_DOUBLE(*value));
         return true;
-    }                
+    }
 
     return false;
 }
@@ -1429,7 +1487,8 @@ class ScriptablePluginObject:public ScriptablePluginObjectBase {
   public:
     ScriptablePluginObject(NPP npp)
     :ScriptablePluginObjectBase(npp) {
-    } virtual bool HasMethod(NPIdentifier name);
+    }
+    virtual bool HasMethod(NPIdentifier name);
     virtual bool Invoke(NPIdentifier name, const NPVariant * args,
                         uint32_t argCount, NPVariant * result);
     virtual bool InvokeDefault(const NPVariant * args, uint32_t argCount, NPVariant * result);
@@ -1449,7 +1508,7 @@ DECLARE_NPOBJECT_CLASS_WITH_BASE(ScriptablePluginObject, AllocateScriptablePlugi
 
 bool ScriptablePluginObject::HasMethod(NPIdentifier name)
 {
-    if (name == Play_id || 
+    if (name == Play_id ||
         name == PlayAt_id ||
         name == Pause_id ||
         name == PlayPause_id ||
@@ -1487,12 +1546,10 @@ bool ScriptablePluginObject::HasMethod(NPIdentifier name)
         name == onMediaComplete_id ||
         name == onMouseUp_id ||
         name == onMouseDown_id ||
-        name == onMouseOut_id ||
-        name == onMouseOver_id ||
-        name == onDestroy_id ) {
-            return true;
+        name == onMouseOut_id || name == onMouseOver_id || name == onDestroy_id) {
+        return true;
     } else {
-            return false;
+        return false;
     }
 }
 
@@ -1513,7 +1570,7 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
         pPlugin->Play();
         return PR_TRUE;
     }
-        
+
     if (name == Pause_id || name == DoPause_id) {
         pPlugin->Pause();
         return PR_TRUE;
@@ -1551,7 +1608,7 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
 
     if (name == GetFileName_id || name == GetHREF_id || name == GetURL_id) {
         pPlugin->GetFilename(&s);
-        STRINGZ_TO_NPVARIANT(s,*result);
+        STRINGZ_TO_NPVARIANT(s, *result);
         g_free(s);
         return PR_TRUE;
     }
@@ -1563,7 +1620,7 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
 
     if (name == GetVolume_id) {
         pPlugin->GetVolume(&d);
-        DOUBLE_TO_NPVARIANT(d,*result);
+        DOUBLE_TO_NPVARIANT(d, *result);
         return PR_TRUE;
     }
 
@@ -1574,37 +1631,37 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
 
     if (name == GetIsLooping_id) {
         pPlugin->GetLoop(&b);
-        BOOLEAN_TO_NPVARIANT(b,*result);
+        BOOLEAN_TO_NPVARIANT(b, *result);
         return PR_TRUE;
     }
 
     if (name == SetAutoPlay_id || name == GetAutoPlay_id) {
-            
+
         return PR_TRUE;
     }
 
     if (name == GetMIMEType_id) {
         pPlugin->GetMIMEType(&s);
-        STRINGZ_TO_NPVARIANT(s,*result);
+        STRINGZ_TO_NPVARIANT(s, *result);
         g_free(s);
         return PR_TRUE;
     }
 
-    if (name == getTime_id ) {
+    if (name == getTime_id) {
         pPlugin->GetTime(&d);
-        DOUBLE_TO_NPVARIANT(d,*result);
+        DOUBLE_TO_NPVARIANT(d, *result);
         return PR_TRUE;
     }
 
     if (name == getDuration_id) {
         pPlugin->GetDuration(&d);
-        DOUBLE_TO_NPVARIANT(d,*result);
+        DOUBLE_TO_NPVARIANT(d, *result);
         return PR_TRUE;
     }
 
     if (name == getPercent_id) {
         pPlugin->GetPercent(&d);
-        DOUBLE_TO_NPVARIANT(d,*result);
+        DOUBLE_TO_NPVARIANT(d, *result);
         return PR_TRUE;
     }
 
@@ -1666,9 +1723,7 @@ bool ScriptablePluginObject::HasProperty(NPIdentifier name)
         name == src_id ||
         name == ShowControls_id ||
         name == fullscreen_id ||
-        name == showlogo_id ||
-        name == playState_id ||
-        name == controls_id) {
+        name == showlogo_id || name == playState_id || name == controls_id) {
         return true;
     } else {
         return false;
@@ -1690,36 +1745,36 @@ bool ScriptablePluginObject::GetProperty(NPIdentifier name, NPVariant * result)
 
     if (name == filename_id || name == src_id) {
         pPlugin->GetFilename(&filename);
-        STRINGZ_TO_NPVARIANT(filename,*result);
+        STRINGZ_TO_NPVARIANT(filename, *result);
         return true;
-    }                
+    }
 
     if (name == ShowControls_id) {
         pPlugin->GetShowControls(&setting);
-        BOOLEAN_TO_NPVARIANT(setting,*result);
+        BOOLEAN_TO_NPVARIANT(setting, *result);
         return true;
-    }    
+    }
 
     if (name == fullscreen_id) {
         pPlugin->GetFullScreen(&setting);
-        BOOLEAN_TO_NPVARIANT(setting,*result);
+        BOOLEAN_TO_NPVARIANT(setting, *result);
         return true;
-    }    
+    }
 
     if (name == showlogo_id) {
         setting = true;
-        BOOLEAN_TO_NPVARIANT(setting,*result);
+        BOOLEAN_TO_NPVARIANT(setting, *result);
         return true;
-    }    
+    }
 
     if (name == playState_id) {
         pPlugin->GetPlayState(&state);
-        INT32_TO_NPVARIANT(state,*result);
+        INT32_TO_NPVARIANT(state, *result);
         return true;
-    }    
+    }
 
     if (name == controls_id) {
-        OBJECT_TO_NPVARIANT(pPlugin->GetScriptableObjectControls(),*result);
+        OBJECT_TO_NPVARIANT(pPlugin->GetScriptableObjectControls(), *result);
         return true;
     }
 
@@ -1738,26 +1793,26 @@ bool ScriptablePluginObject::SetProperty(NPIdentifier name, const NPVariant * va
     if (name == filename_id || name == src_id) {
         pPlugin->SetFilename(NPVARIANT_TO_STRING(*value).utf8characters);
         return true;
-    }                
+    }
 
     if (name == ShowControls_id) {
         pPlugin->SetShowControls(NPVARIANT_TO_BOOLEAN(*value));
         return true;
-    }    
+    }
 
     if (name == fullscreen_id) {
         pPlugin->SetFullScreen(NPVARIANT_TO_BOOLEAN(*value));
         return true;
-    }    
+    }
 
     if (name == showlogo_id) {
         return true;
-    }    
+    }
 
     if (name == playState_id) {
         // readonly property
         return true;
-    }    
+    }
 
     return false;
 }
@@ -1789,5 +1844,3 @@ NPObject *CPlugin::GetScriptableObjectControls()
 
     return m_pScriptableObjectControls;
 }
-
-
