@@ -85,6 +85,15 @@
 #define DEBUG_LEVEL		"debug_level"
 #define DISABLE_MIDI    "disable_midi"
 
+typedef enum {
+    PLAYING,
+    PAUSED,
+    STOPPED,
+    QUIT
+} PLAYSTATE;
+
+void postDOMEvent(NPP mInstance, const gchar * id, const gchar * event);
+
 class CPlugin {
   private:
     NPWindow * m_Window;
@@ -179,6 +188,7 @@ class CPlugin {
     gchar *id;
     gchar *console;
     gchar *controls;
+    gchar *user_agent;
 
     // events
     gboolean post_dom_events;
@@ -203,4 +213,7 @@ class CPlugin {
 
 };
 
+void pluginSpecific(CPlugin * instance);
+void setPreference(CPlugin * instance, const gchar * name, const gchar * value);
+
 #endif                          // __PLUGIN_H__
