@@ -40,7 +40,7 @@
 gchar *GetMIMEDescription()
 {
     gchar MimeTypes[4000];
-    GmPrefStore * store;
+    GmPrefStore *store;
     gboolean qt_disabled = FALSE;
 
     g_type_init();
@@ -97,3 +97,9 @@ NPError PluginGetValue(NPPVariable variable, void *value)
 
 
 }
+
+void pluginSpecific(CPlugin * instance)
+{
+    setPreference(instance, "general.useragent.override", "QuickTime/7.6.2");
+}
+
